import request from '@/utils/request'

// 查询（未编制）
export function searchPartNum1(num1, start, end, pageCurrent, pageSize) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: '外协价格预算查询零件_MESWORK',
      param: '零件图号=' + num1 + '&开始时间=' + start + '&结束时间=' + end,
      Pagination: pageCurrent + '&' + pageSize
    }
  })
}
// 查询零件号（已编制）
export function searchPartNum2(num, start, end, pageCurrent, pageSize) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: '外协价格预算查询零件已编制_MESWORK',
      param: '零件图号=' + num + '&开始时间=' + start + '&结束时间=' + end,
      Pagination: pageCurrent + '&' + pageSize
    }
  })
}

// 查询零件工艺
export function searchTable(num, outHelp) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: '车间生产管理工艺_零件工序_查询数据_根据工艺计划流水号_新',
      param: '工艺计划流水号=' + num + '&单件是否外协=' + outHelp
    }
  })
}
// 保存重量面积
export function saveWeightArea(num, weight, area) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '2',
      name: '车间生产管理工艺_零件工艺计划_修改数据_重量面积',
      param: '工艺计划流水号=' + num + '&重量=' + weight + '&面积=' + area
    }
  })
}
// 保存材料费
export function saveMaterialPrice(num, price) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '2',
      name: '车间生产管理工艺_零件工艺计划_修改数据_材料费',
      param: '工艺计划流水号=' + num + '&材料费=' + price
    }
  })
}
// 保存每行价格
export function saveRowPrice(num1, price1, num2, price2) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '2',
      name: '车间生产管理工艺_零件工序_修改数据_外协预算价格_系数',
      param: '工序流水号=' + num1 + '&外协预算价格=' + price1 + '&工艺计划流水号=' + num2 + '&材料费=' + price2
    }
  })
}
